//////////////////////////////////////////////////////////////////////////
//
//	Vital Systems Inc. Copyright (c) 2003 - All Rights Reserved.
//
//	Description: WDM driver generic interface.
//
//  Revision History :
//  Version		Date		Developer	Comment
//	1.0			10/6/01		AR	
//	2.0			4/22/03		AR			Channel Based driver update	
//
//////////////////////////////////////////////////////////////////////////

#ifndef CANDRVBASE_DRIVER_H_
#define CANDRVBASE_DRIVER_H_

class CCANet
{

public:

	CCANet() : mStarted(0) {}

	// Device Driver Up and running Flag.  Must check this value after instantiating the class
	// It will be false if the driver is not started/installed. Calls will fail if false.
	const bool mStarted;

	// Rcv CAN message from driver internal queue (NonBlocking Call)
	virtual BOOL GetMsg( ULONG& Identifier, UCHAR* Msg, UCHAR& MsgSize ) = 0;

	// Send CAN Bus Message
	virtual BOOL SendMsg( ULONG Identifier, UCHAR* Msg, UCHAR MsgSize ) = 0;

	// Empty RCV Que for this channel. Rcv Queue size is 200 messeges
	virtual BOOL ResetMsgQue() = 0;

	// Control the LEDs on bracket. 1 tick = 10mSec
	virtual void BlinkCommsLED( UCHAR ticks ) = 0;
	virtual void BlinkErrorLED( UCHAR ticks ) = 0;

	// Get number of boards installed
	virtual BOOL GetBoardCount( UCHAR &Count ) = 0;

	// Set CAN parameter for 16 Mhz crystal.

	// BusSpeed	125 kbps	250 kbps	500 Kbps	1 Mbps
	// BTR0		3			1			0			0
	// BTR1		0x1C		0x1C		0x1C		0x14

	virtual BOOL SetBusParam( UCHAR BTr0, UCHAR BTr1,
							  UCHAR ACr0, UCHAR ACr1,
							  UCHAR ACr2, UCHAR ACr3,
							  UCHAR AMr0, UCHAR AMr1,
							  UCHAR AMr2, UCHAR AMr3 ) = 0;

	virtual BOOL SetBusParam( UCHAR BTr0, UCHAR BTr1, 
							  ULONG Ident1, ULONG Mask1,
							  ULONG Ident2, ULONG Mask2 ) = 0;

	// Get error counters
	virtual BOOL GetErrorCounters( UINT &NetError, UINT &TxOverRuns, UINT &RxOverRuns ) = 0;

	// reset error counter
	virtual BOOL ResetErrorCounters() = 0;

	virtual BOOL DisableCAN() = 0;

protected:
	HANDLE m_hDriver;
	UCHAR m_AbsChannel;
};


#endif
